#!/usr/bin/python3
"""
## © University of Southampton IT Innovation Centre, 2018
##
## Copyright in this software belongs to University of Southampton
## IT Innovation Centre of Gamma House, Enterprise Road, 
## Chilworth Science Park, Southampton, SO16 7NS, UK.
##
## This software may not be used, sold, licensed, transferred, copied
## or reproduced in whole or in part in any manner or form or in or
## on any media by any person other than in accordance with the terms
## of the Licence Agreement supplied with the software, or otherwise
## without the prior written consent of the copyright owners.
##
## This software is distributed WITHOUT ANY WARRANTY, without even the
## implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
## PURPOSE, except where stated in the Licence Agreement supplied with
## the software.
##
##      Created By :            Michael Boniface
##      Created Date :          25-02-2018
##      Updated By :            Nikolay Stanchev
##      Updated Date :          30-08-2018
##      Created for Project :   FLAME
"""

import pytest
import json
import pkg_resources
from influxdb import InfluxDBClient
from clmctest.monitoring.StreamingSim import Sim


@pytest.fixture(scope="module")
def streaming_sim_config():
    """
    Reads the service configuration deployed for the streaming simulation test.

    :return: the python object representing the read JSON file
    """

    rspec = pkg_resources.resource_filename('clmctest', 'rspec.json')
    print("\nrspec file: {0}".format(rspec))

    with open(rspec, 'r') as stream:
        data_loaded = json.load(stream)
    return data_loaded


@pytest.fixture(params=[{'database': 'media_service_A'}], scope='module')
def influx_db(streaming_sim_config, request):
    """
    Creates an Influx DB client for the CLMC metrics database

    :param streaming_sim_config: the fixture returning the yaml configuration
    :param request: access the parameters of the fixture
    :return: the created Influx DB client
    """

    return InfluxDBClient(host=streaming_sim_config[0]['ip_address'], port='8086', database=request.param['database'], timeout=10)


@pytest.fixture(scope="module")
def simulator(streaming_sim_config):
    """
    A fixture to obtain a simulator instance with the configuration parameters.

    :param streaming_sim_config: the configuration object
    :return: an instance of the simulator
    """

    influx_url = "http://" + streaming_sim_config[0]['ip_address'] + ":8086"

    agent1_url, agent2_url = None, None
    for service in streaming_sim_config:
        if service['name'] == "ipendpoint1":
            influx_db_name = service['sfc_id']
            agent1_url = "http://" + service['ip_address'] + ":8186"
        elif service['name'] == "ipendpoint2":
            agent2_url = "http://" + service['ip_address'] + ":8186"

        if agent1_url is not None and agent2_url is not None:
            break

    assert agent1_url is not None, "Configuration error for ipendpoint1"
    assert agent2_url is not None, "Configuration error for ipendpoint2"

    simulator = Sim(influx_url, influx_db_name, agent1_url, agent2_url)

    simulator.reset()

    return simulator
